aboutsummaryrefslogtreecommitdiffstats
path: root/vendor/github.com/nakabonne
diff options
context:
space:
mode:
authorTaras Madan <tarasmadan@google.com>2022-09-05 14:27:54 +0200
committerGitHub <noreply@github.com>2022-09-05 12:27:54 +0000
commitb2f2446b46bf02821d90ebedadae2bf7ae0e880e (patch)
tree923cf42842918d6bebca1d6bbdc08abed54d274d /vendor/github.com/nakabonne
parente6654faff4bcca4be92e9a8596fd4b77f747c39e (diff)
go.mod, vendor: update (#3358)
* go.mod, vendor: remove unnecessary dependencies Commands: 1. go mod tidy 2. go mod vendor * go.mod, vendor: update cloud.google.com/go Commands: 1. go get -u cloud.google.com/go 2. go mod tidy 3. go mod vendor * go.mod, vendor: update cloud.google.com/* Commands: 1. go get -u cloud.google.com/storage cloud.google.com/logging 2. go mod tidy 3. go mod vendor * go.mod, .golangci.yml, vendor: update *lint* Commands: 1. go get -u golang.org/x/tools github.com/golangci/golangci-lint@v1.47.0 2. go mod tidy 3. go mod vendor 4. edit .golangci.yml to suppress new errors (resolved in the same PR later) * all: fix lint errors hash.go: copy() recommended by gosimple parse.go: ent is never nil verifier.go: signal.Notify() with unbuffered channel is bad. Have no idea why. * .golangci.yml: adjust godot rules check-all is deprecated, but still work if you're hesitating too - I'll remove this commit
Diffstat (limited to 'vendor/github.com/nakabonne')
-rw-r--r--vendor/github.com/nakabonne/nestif/README.md8
-rw-r--r--vendor/github.com/nakabonne/nestif/go.mod2
-rw-r--r--vendor/github.com/nakabonne/nestif/nestif.go6
3 files changed, 11 insertions, 5 deletions
diff --git a/vendor/github.com/nakabonne/nestif/README.md b/vendor/github.com/nakabonne/nestif/README.md
index ede411f73..37d370175 100644
--- a/vendor/github.com/nakabonne/nestif/README.md
+++ b/vendor/github.com/nakabonne/nestif/README.md
@@ -2,16 +2,22 @@
[![Go Doc](https://img.shields.io/badge/godoc-reference-blue.svg?style=flat-square)](http://godoc.org/github.com/nakabonne/nestif)
-Reports deeply nested if statements in Go code, by calculating its complexities based on the rules defined by the [Cognitive Complexity white paper by G. Ann Campbell](https://www.sonarsource.com/docs/CognitiveComplexity.pdf).
+Reports complex nested if statements in Go code, by calculating its complexities based on the rules defined by the [Cognitive Complexity white paper by G. Ann Campbell](https://www.sonarsource.com/docs/CognitiveComplexity.pdf).
It helps you find if statements that make your code hard to read, and clarifies which parts to refactor.
## Installation
+### By go get
+
```
go get github.com/nakabonne/nestif/cmd/nestif
```
+### By golangci-lint
+
+`nestif` is already integrated with [golangci-lint](https://github.com/golangci/golangci-lint). Please refer to the instructions there and enable it.
+
## Usage
### Quick Start
diff --git a/vendor/github.com/nakabonne/nestif/go.mod b/vendor/github.com/nakabonne/nestif/go.mod
index 325901d59..0d5b1f721 100644
--- a/vendor/github.com/nakabonne/nestif/go.mod
+++ b/vendor/github.com/nakabonne/nestif/go.mod
@@ -1,6 +1,6 @@
module github.com/nakabonne/nestif
-go 1.13
+go 1.15
require (
github.com/spf13/pflag v1.0.5
diff --git a/vendor/github.com/nakabonne/nestif/nestif.go b/vendor/github.com/nakabonne/nestif/nestif.go
index d458022fb..c4bad7f2d 100644
--- a/vendor/github.com/nakabonne/nestif/nestif.go
+++ b/vendor/github.com/nakabonne/nestif/nestif.go
@@ -1,10 +1,10 @@
-// Copyright 2020 Ryo Nakao <nakabonne@gmail.com>.
+// Copyright 2020 Ryo Nakao <ryo@nakao.dev>.
//
// All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
// Package nestif provides an API to detect deeply nested if statements.
package nestif
import (
@@ -133,7 +133,7 @@ func (c *Checker) makeMessage(complexity int, cond ast.Expr, fset *token.FileSet
if err := p.Fprint(b, fset, cond); err != nil {
c.debug("failed to convert condition into string: %v", err)
}
- return fmt.Sprintf("`if %s` is deeply nested (complexity: %d)", b.String(), complexity)
+ return fmt.Sprintf("`if %s` has complex nested blocks (complexity: %d)", b.String(), complexity)
}
// DebugMode makes it possible to emit debug logs.
@@ -1,10 +1,10 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
-// Package nestif provides an API to detect deeply nested if statements.
+// Package nestif provides an API to detect complex nested if statements.
package nestif
import (